createComponentList method
ComponentList
createComponentList()
inherited
This method creates the children container for the current component.
Override this method if you need a customized ComponentList for a
particular class, for example one with a custom ordering:
@override
ComponentList createComponentList() {
return ComponentList(
comparator: (a, b) => a.someValue.compareTo(b.someValue),
);
}
Implementation
ComponentList createComponentList() => ComponentList();