game library
Classes
- Aabb3
- Defines a 3-dimensional axis-aligned bounding box between a min and a max position.
-
FlameGame3D<
W extends World3D, C extends CameraComponent3D> - Matrix2
- 2D Matrix. Values are stored in column major order.
- Matrix3
- 3D Matrix. Values are stored in column major order.
- Matrix4
- 4D Matrix. Values are stored in column major order.
- NotifyingQuaternion
- Extension of the standard Quaternion class, implementing the ChangeNotifier functionality. This allows any interested party to be notified when the value of this quaternion changes.
- NotifyingVector3
- Extension of the standard Vector3 class, implementing the ChangeNotifier functionality. This allows any interested party to be notified when the value of this vector changes.
- Quaternion
- Defines a Quaternion (a four-dimensional vector) for efficient rotation calculations.
- QuaternionUtils
- Transform3D
- This class describes a generic 3D transform, which is a combination of translations, rotations and scaling. These transforms are combined into a single matrix, that can be either applied to a graphical device like the canvas, composed with another transform, or used directly to convert coordinates.
- UnmodifiableVector3
- Extension of the standard Vector3 class, but fully unmodifiable.
- Vector2
- 2D column vector.
- Vector2Utils
- Vector3
- 3D column vector.
- Vector3Utils
- Vector4
- 4D column vector.
- Vector4Utils
Enums
- CullResult
- Result of a frustum-AABB intersection test.
Mixins
Extensions
- Aabb3Extension on Aabb3
- ColorExtension on Color
- Matrix4Extension on Matrix4
- QuaternionExtension on Quaternion
- UnmodifiableVector3Extension on Vector3
- Vector2Extension on Vector2
- Vector2Math on ImmutableVector2
- Vector3Extension on Vector3
- Vector3Math on ImmutableVector3
- Vector4Extension on Vector4
- Vector4Math on ImmutableVector4
Constants
- degrees2Radians → const double
- Constant factor to convert and angle from degrees to radians.
Functions
-
setOrthographicMatrix(
Matrix4 orthographicMatrix, double left, double right, double bottom, double top, double near, double far) → void -
Constructs an OpenGL orthographic projection matrix in
orthographicMatrix. -
setPerspectiveMatrix(
Matrix4 perspectiveMatrix, double fovYRadians, double aspectRatio, double zNear, double zFar) → void -
Constructs an OpenGL perspective projection matrix in
perspectiveMatrix. -
setViewMatrix(
Matrix4 viewMatrix, Vector3 cameraPosition, Vector3 cameraFocusPosition, Vector3 upDirection) → void -
Constructs an OpenGL view matrix in
viewMatrix. View transformation is the inverse of the model transformation. View matrix is commonly used to compute the camera location/orientation into the full model-view stack.
Typedefs
- ImmutableVector2 = ({double x, double y})
- Represents an immutable Vector2.
- ImmutableVector3 = ({double x, double y, double z})
- Represents an immutable Vector3.
- ImmutableVector4 = ({double w, double x, double y, double z})
- Represents an immutable Vector3.