UnmodifiableVector3.all constructor
UnmodifiableVector3.all(
- double v
Extension of the standard Vector3 class, but fully unmodifiable.
This class can be used as a regular Vector3 class. However, if you do try to write values the calls will throw.
Direct modification of this vector's storage is not allowed.
Create an vector whose values are all v.
Implementation
factory UnmodifiableVector3.all(double v) =>
UnmodifiableVector3.zero().._setValues(v, v, v);