UnmodifiableVector3.zero constructor

UnmodifiableVector3.zero()

Extension of the standard Vector3 class, but fully unmodifiable.

This class can be used as a regular Vector3 class. However, if you do try to write values the calls will throw.

Direct modification of this vector's storage is not allowed.

Create an empty vector.

Implementation

UnmodifiableVector3.zero() : super.zero();