graphics library

Classes

GpuBackend
A rendering backend: the abstraction over a concrete low-level GPU API.
GpuBuffer
Handle to a GPU buffer holding vertex/index data.
GpuBufferView
A windowed view over a region of a GpuBuffer.
GpuFrame
A single frame of rendering.
GpuPipeline
Handle to a compiled render pipeline.
GpuRenderPass
Records the bind and draw commands of a single render pass.
GpuRenderTarget
Handle to a render target.
GpuShader
Handle to a compiled shader stage.
GpuShaderLibrary
A collection of compiled shaders loaded from a single asset bundle.
GpuTexture
Handle to a GPU texture.
GpuUniformSlot
A uniform or sampler slot within a GpuShader.
GraphicsDevice
The GraphicsDevice provides a way for developers to interact with the GPU by binding different resources to it.
RenderContext
RenderContext3D

Enums

BlendState
Color blending mode for a render pass output.
CullMode
Face culling mode. Controls which triangle faces are discarded before rasterization.
DepthStencilState
Depth buffer behavior for a render pass.
GpuIndexType
Width of the integers stored in an index buffer.
GpuPixelFormat
Pixel layout of a GPU texture.
GpuStorageMode
How a GPU resource's memory is allocated and accessed.