DepthStencilState enum

Depth buffer behavior for a render pass.

Inheritance
Available extensions

Values

standard → const DepthStencilState

Depth test and write enabled (normal opaque 3D rendering). Fragments closer than the stored depth pass and update the buffer.

depthRead → const DepthStencilState

Depth test enabled, write disabled (transparent objects). Fragments are tested against existing depth but don't update it.

none → const DepthStencilState

No depth testing, all fragments pass regardless of depth.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DepthStencilState>
A constant List of the values in this enum, in order of their declaration.