GpuBuffer class abstract interface

Handle to a GPU buffer holding vertex/index data.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(ByteData data, {int destinationOffsetInBytes = 0}) → void
Uploads data into the buffer starting at destinationOffsetInBytes.

Operators

operator ==(Object other) bool
The equality operator.
inherited