GpuPixelFormat enum

Pixel layout of a GPU texture.

Inheritance
Available extensions

Values

rgba8888 → const GpuPixelFormat

8 bits per channel, RGBA order.

bgra8888 → const GpuPixelFormat

8 bits per channel, BGRA order.

rgbaFloat32 → const GpuPixelFormat

32-bit float per channel, RGBA order.

depthStencil → const GpuPixelFormat

The backend's default depth/stencil format.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GpuPixelFormat>
A constant List of the values in this enum, in order of their declaration.