Handle to a GPU texture.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asImage(
) → Image - Returns the texture's contents as an Image.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
ByteData data) → void -
Uploads
datato the texture.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited