sizeInBytes property
int?
get
sizeInBytes
Size of the uniform block in bytes, or null when this slot is a
sampler.
Implementation
int? get sizeInBytes;
Size of the uniform block in bytes, or null when this slot is a
sampler.
int? get sizeInBytes;