backend property
The GPU backend this device records its rendering commands through.
Implementation
final GpuBackend backend = backend ?? GpuBackend.instance;
The GPU backend this device records its rendering commands through.
final GpuBackend backend = backend ?? GpuBackend.instance;