clearBindings method
void
clearBindings()
Clear all resources bound to the current render pass.
Implementation
void clearBindings() {
_renderPass.clearBindings();
}
Clear all resources bound to the current render pass.
void clearBindings() {
_renderPass.clearBindings();
}