AnimationController<T> class

Allows sampling of an animation by interpolating keyframes.

Constructors

AnimationController({required AnimationSpline<T> animation})

Properties

animation → AnimationSpline<T>
final
hashCode → int
The hash code for this object.
no setterinherited
lastTime → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sample(double time) → T
sampleInto(double time, Matrix4 matrix) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited