ModelJoint class

A single join inside a ModelNode.

Constructors

ModelJoint({required int nodeIndex, required Matrix4 inverseBindMatrix})

Properties

hashCode → int
The hash code for this object.
no setterinherited
inverseBindMatrix → Matrix4
final
nodeIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited