ModelNode class

A node wraps over a mesh as part of a 3D model, including its joints and local transformations.

Constructors

ModelNode({required String? name, required int nodeIndex, required int? parentNodeIndex, required Matrix4 transform, required Mesh? mesh, required Map<int, ModelJoint> joints})
ModelNode.simple({required int nodeIndex, required Mesh? mesh})

Properties

dependencies → List<int>
no setter
hashCode → int
The hash code for this object.
no setterinherited
joints → Map<int, ModelJoint>
final
mesh → Mesh?
final
name → String?
final
nodeIndex → int
final
parentNodeIndex → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform → Matrix4
final

Methods

computeJointsPerSurface(Map<int, ProcessedNode> processedNodes) → Map<int, List<Matrix4>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processNode(Map<int, ProcessedNode> processedNodes, AnimationState animation) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited