resources library

Classes

AmbientLight
ColorTexture
A texture that holds a single color. By default it creates a 1x1 texture.
ConeMesh
A conical mesh, with base on the x-z plane, centered origin; and tip pointing upwards parallel to the y-axis.
CuboidMesh
Represents a Cuboid's geometry with a single surface.
CylinderMesh
FragmentShader
A Shader that runs per-fragment (pixel) during rasterization.
ImageTexture
A texture that holds an image as it's render-able texture.
Light
A Resource that represents a light source that is positioned in the scene and changes how other objects are rendered.
LightSource
Describes the properties of a light source. There are three types of light sources: point, directional, and spot. Currently only PointLight is implemented.
Material
Base material Resource, it holds the shader library that should be used for the material.
Mesh
A Resource that represents a geometric shape that is divided up in one or more Surfaces.
PlaneMesh
Represents a 2D Plane's geometry with a single surface.
PointLight
A point light that emits light in all directions equally.
Resource<R>
A Resource is the base class for any resource typed classes. The primary use case is to be a data container.
Shader
A shader Resource that represents a compiled shader program and the uniform data that will be bound to it.
SpatialMaterial
SphereMesh
Represents a Sphere's geometry with a single surface.
Surface
Base surface Resource, it describes a single surface to be rendered.
Texture
Base texture Resource, represents an image/texture on the GPU.
Vertex
Represents a vertex in 3D space.
VertexShader
A Shader that runs per-vertex to transform geometry from model space to screen space.

Extensions

TextureCache on Images