ColorTexture class

A texture that holds a single color. By default it creates a 1x1 texture.

Inheritance

Constructors

ColorTexture(Color color, {int width = 1, int height = 1})
A texture that holds a single color. By default it creates a 1x1 texture.

Properties

format → PixelFormat
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
finalinherited
recreateResource ↔ bool
getter/setter pairinherited
resource → GpuTexture
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceData → ByteData
finalinherited
width → int
finalinherited

Methods

createResource() → GpuTexture
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImage() → Image
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited