CuboidMesh class

Represents a Cuboid's geometry with a single surface.

Inheritance

Constructors

CuboidMesh({required Vector3 size, Material? material, bool useFaceNormals = true})
Represents a Cuboid's geometry with a single surface.

Properties

aabb Aabb3
The AABB of the mesh.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
recreateResource bool
getter/setter pairinherited
resource → void
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Vector3
The full size of the cuboid along each axis.
final
surfaceCount int
The total surface count of the mesh.
no setterinherited
surfaces Iterable<Surface>
An unmodifiable iterable over the list of the surfaces.
no setterinherited
vertexCount int
no setterinherited

Methods

addSurface(Surface surface) int
Add a new surface to this mesh. Return the index of the newly added surface. Surfaces are always added to the end of the list.
inherited
createResource() → void
inherited
draw(RenderContext3D context) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSurface(int index) → void
Remove the surface at index.
inherited
toString() String
A string representation of this object.
inherited
updateBounds() → void
Must be called when the mesh has been modified.
inherited
updateSurface(int index, Surface surface) → void
Replace the surface at index with surface.
inherited
updateSurfaces(void update(List<Surface> surfaces)) → void
Update the surfaces of the mesh, making sure to recompute the bounds after.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited