FragmentShader class

A Shader that runs per-fragment (pixel) during rasterization.

Typically used to compute the final color of each pixel based on material properties, lighting, and textures.

Inheritance

Constructors

FragmentShader.fromAsset(String assetName, {String entryPoint = 'TextureFragment', List<String> slots = const []})
A Shader that runs per-fragment (pixel) during rasterization.

Properties

entryPoint String
The shader entry point name within the bundle.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
recreateResource bool
getter/setter pairinherited
resource Shader
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slots List<String>
Names of all uniform slots — both struct blocks and samplers.
finalinherited

Methods

bind(GraphicsDevice device) → void
Bind all uniform data and textures to the device.
inherited
createResource() Shader
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setColor(String key, Color color) → void
Set a Color at the given key.
inherited
setFloat(String key, double value) → void
Set a double at the given key.
inherited
setMatrix2(String key, Matrix2 matrix) → void
Set a Matrix2 at the given key.
inherited
setMatrix3(String key, Matrix3 matrix) → void
Set a Matrix3 at the given key.
inherited
setMatrix4(String key, Matrix4 matrix) → void
Set a Matrix4 at the given key.
inherited
setTexture(String key, Texture texture) → void
Set a Texture at the given key.
inherited
setUint(String key, int value) → void
Set an int (encoded as uint) at the given key.
inherited
setVector2(String key, Vector2 vector) → void
Set a Vector2 at the given key.
inherited
setVector3(String key, Vector3 vector) → void
Set a Vector3 at the given key.
inherited
setVector4(String key, Vector4 vector) → void
Set a Vector4 at the given key.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited