FragmentShader.fromAsset constructor

FragmentShader.fromAsset(
  1. String assetName, {
  2. String entryPoint = 'TextureFragment',
  3. List<String> slots = const [],
})

A Shader that runs per-fragment (pixel) during rasterization.

Typically used to compute the final color of each pixel based on material properties, lighting, and textures.

Implementation

FragmentShader.fromAsset(
  super.assetName, {
  super.entryPoint = 'TextureFragment',
  super.slots = const [],
}) : super.fromAsset();