Light class

A Resource that represents a light source that is positioned in the scene and changes how other objects are rendered.

This class isn't a true resource, it does not upload it self to the GPU. Instead, it is used to modify how other resources are uploaded.

Inheritance

Constructors

Light({required Vector3 position, required LightSource source})
A Resource that represents a light source that is positioned in the scene and changes how other objects are rendered.

Properties

hashCode int
The hash code for this object.
no setterinherited
position Vector3
final
recreateResource bool
getter/setter pairinherited
resource → void
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source LightSource
final

Methods

createResource() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited