Mesh class

A Resource that represents a geometric shape that is divided up in one or more Surfaces.

This class isn't a true resource, it does not upload it self to the GPU. Instead it uploads Surfaces, it acts as a proxy.

Inheritance
Implementers

Constructors

Mesh()
A Resource that represents a geometric shape that is divided up in one or more Surfaces.

Properties

aabb → Aabb3
The AABB of the mesh.
no setter
hashCode → int
The hash code for this object.
no setterinherited
recreateResource ↔ bool
getter/setter pairinherited
resource → void
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surfaceCount → int
The total surface count of the mesh.
no setter
surfaces → Iterable<Surface>
An unmodifiable iterable over the list of the surfaces.
no setter
vertexCount → int
no setter

Methods

addSurface(Surface surface) → int
Add a new surface to this mesh. Return the index of the newly added surface. Surfaces are always added to the end of the list.
createResource() → void
override
draw(RenderContext3D context) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSurface(int index) → void
Remove the surface at index.
toString() → String
A string representation of this object.
inherited
updateBounds() → void
Must be called when the mesh has been modified.
updateSurface(int index, Surface surface) → void
Replace the surface at index with surface.
updateSurfaces(void update(List<Surface> surfaces)) → void
Update the surfaces of the mesh, making sure to recompute the bounds after.

Operators

operator ==(Object other) → bool
The equality operator.
inherited