SpatialMaterial class

Inheritance

Constructors

SpatialMaterial({Color albedoColor = const Color(0xFFFFFFFF), Texture? albedoTexture, double metallic = 0.8, double roughness = 0.6})

Properties

albedoColor ↔ Color
The material's base color.
getter/setter pair
albedoTexture ↔ Texture
The texture that will be multiplied by albedoColor.
getter/setter pair
cullMode ↔ CullMode
Face culling mode for this material. Defaults to CullMode.none.
getter/setter pairinherited
fragmentShader ↔ Shader
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
metallic ↔ double
getter/setter pair
recreateResource ↔ bool
getter/setter pairinherited
resource → GpuPipeline
no setterinherited
roughness ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexShader ↔ Shader
getter/setter pairinherited

Methods

apply(covariant RenderContext3D context) → void
override
createResource() → GpuPipeline
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited