Surface class

Base surface Resource, it describes a single surface to be rendered.

Inheritance

Constructors

Surface({required List<Vertex> vertices, required List<int> indices, Material? material, Map<int, int>? jointMap, bool calculateNormals = true})
Base surface Resource, it describes a single surface to be rendered.

Properties

aabb Aabb3
no setter
hashCode int
The hash code for this object.
no setterinherited
indexCount int
no setter
indices Uint16List
The triangle indices for this surface. Computed once during construction.
latefinal
indicesBytes int
no setter
jointMap Map<int, int>?
getter/setter pair
material Material
getter/setter pair
positions Float32List
The (x, y, z) positions of this surface's vertices, packed contiguously as [x0, y0, z0, x1, y1, z1, ...].
latefinal
recreateResource bool
getter/setter pairinherited-setteroverride-getter
resource GpuBuffer
no setterinherited
resourceSizeInByes int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertexCount int
no setter
verticesBytes int
no setter

Methods

createResource() GpuBuffer
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited