Texture class

Base texture Resource, represents an image/texture on the GPU.

Inheritance
Implementers

Constructors

Texture(ByteData sourceData, {required int width, required int height, PixelFormat format = PixelFormat.rgba8888})
Base texture Resource, represents an image/texture on the GPU.

Properties

format → PixelFormat
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
recreateResource ↔ bool
getter/setter pairinherited
resource → GpuTexture
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceData → ByteData
final
width → int
final

Methods

createResource() → GpuTexture
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImage() → Image
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

empty → ColorTexture
A transparent single pixel texture.
final
standard → ColorTexture
A white single pixel texture.
final