UnmodifiableVector3 constructor
Extension of the standard Vector3 class, but fully unmodifiable.
This class can be used as a regular Vector3 class. However, if you do try to write values the calls will throw.
Direct modification of this vector's storage is not allowed.
Constructs a vector using the raw values x, y, and z.
Implementation
factory UnmodifiableVector3(double x, double y, double z) =>
UnmodifiableVector3.zero().._setValues(x, y, z);