GpuBufferView class
A windowed view over a region of a GpuBuffer.
Constructors
- GpuBufferView(GpuBuffer buffer, {required int offsetInBytes, required int lengthInBytes})
-
Creates a view over
bufferspanninglengthInBytesbytes starting atoffsetInBytes.const
Properties
- buffer → GpuBuffer
-
The buffer this view refers into.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lengthInBytes → int
-
Length of the view in bytes.
final
- offsetInBytes → int
-
Byte offset of the view within buffer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited