A uniform or sampler slot within a GpuShader.
Uniform blocks report a non-null sizeInBytes while samplers report null.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeInBytes → int?
-
Size of the uniform block in bytes, or
nullwhen this slot is a sampler.no setter
Methods
-
getMemberOffsetInBytes(
String member) → int? -
Byte offset of
memberwithin the uniform block, ornullwhen the member does not exist. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited