GraphicsDevice constructor
GraphicsDevice({
- Color clearValue = const Color(0x00000000),
- GpuBackend? backend,
The GraphicsDevice provides a way for developers to interact with the GPU by binding different resources to it.
A frame starts with begin and ends with end. Within a frame, one or more render passes can be created with beginPass/endPass, each producing an Image.
Implementation
GraphicsDevice({
this.clearValue = const Color(0x00000000),
GpuBackend? backend,
}) : backend = backend ?? GpuBackend.instance;