begin method
void
begin()
Begin a new frame.
Starts the frame whose transient storage is shared across all render passes. Call end when the frame is complete.
Implementation
void begin() {
// Reset the pool indices, each existing target becomes available again.
_poolIndex.updateAll((_, __) => 0);
_frame = backend.beginFrame();
}