FragmentShader.fromAsset constructor
FragmentShader.fromAsset(})
A Shader that runs per-fragment (pixel) during rasterization.
Typically used to compute the final color of each pixel based on material properties, lighting, and textures.
Implementation
FragmentShader.fromAsset(
super.assetName, {
super.entryPoint = 'TextureFragment',
super.slots = const [],
}) : super.fromAsset();