VertexShader.fromAsset constructor
VertexShader.fromAsset(})
A Shader that runs per-vertex to transform geometry from model space to screen space.
Typically used to apply model, view, and projection transforms, as well as skeletal animation via joint matrices.
Implementation
VertexShader.fromAsset(
super.assetName, {
super.entryPoint = 'TextureVertex',
super.slots = const [],
}) : super.fromAsset();